@@ -19,8 +19,6 @@ settings.configure(
         'recommends',
         'recommends.storages.djangoorm',
         'recommends.tests',
-        'celery',
-        'djcelery',
     ],
     ROOT_URLCONF='recommends.tests.urls',
     TEMPLATE_DIRS=(
